@@ -8,8 +8,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2005-11-14 14:03:29 +0100 (Mon, 14 Nov 2005) $ by $Author: zayenz $
- *     $Revision: 2552 $
+ *     $Date: 2006-03-30 14:25:12 +0200 (Thu, 30 Mar 2006) $ by $Author: zayenz $
+ *     $Revision: 3132 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,8 +35,8 @@ namespace {
   int x = 1;
 
   void seed(unsigned int val) {
-    if(val) x = val % m;
-    else    val = 1;
+    x = val % m;
+    if (x == 0) x = 1;
   }
   
   unsigned int randimp() {
